import os
import pytest

import vegaapiclient as vac


@pytest.fixture(scope='module')
def tradingGRPC():
    grpc_node = os.getenv("GRPC_NODE")
    assert grpc_node is not None and grpc_node != ""
    return vac.VegaTradingClient(vac.API.GRPC, grpc_node)


@pytest.fixture(scope='module')
def tradingdataGRPC():
    grpc_node = os.getenv("GRPC_NODE")
    assert grpc_node is not None and grpc_node != ""
    return vac.VegaTradingDataClient(vac.API.GRPC, grpc_node)


@pytest.fixture(scope='module')
def tradingREST():
    rest_node = os.getenv("REST_NODE")
    assert rest_node is not None and rest_node != ""
    return vac.VegaTradingClient(vac.API.REST, rest_node)


@pytest.fixture(scope='module')
def tradingdataREST():
    rest_node = os.getenv("REST_NODE")
    assert rest_node is not None and rest_node != ""
    return vac.VegaTradingDataClient(vac.API.REST, rest_node)



import requests

from typing import Any, Dict, List


class WalletClient(object):

    def __init__(
        self,
        url: str
    ):
        self.token = ""
        self.url = url

        self._httpsession = requests.Session()

    def _header(self) -> Dict[str, Any]:
        if self.token == "":
            raise Exception("not logged in")
        return {"Authorization": "Bearer " + self.token}

    def create(
        self,
        walletname: str,
        passphrase: str
    ) -> requests.Response:
        """
        Create a wallet using a wallet name and a passphrase. If a wallet
        already exists, the action fails. Otherwise, a JWT (json web token) is
        returned.
        """
        req = {
            "wallet": walletname,
            "passphrase": passphrase
        }
        r = self._httpsession.post(self.url + "/api/v1/wallets", json=req)
        if r.status_code != 200:
            self.token = ""
        else:
            self.token = r.json()["Data"]
        return r

    def login(
        self,
        walletname: str,
        passphrase: str
    ) -> requests.Response:
        """
        Log in to an existing wallet. If the wallet does not exist, or if the
        passphrase is incorrect, the action fails. Otherwise, a JWN (json web
        token) is returned.
        """
        req = {
            "wallet": walletname,
            "passphrase": passphrase
        }
        r = self._httpsession.post(
            "{}/api/v1/auth/token".format(self.url), json=req)
        if r.status_code == 200:
            self.token = r.json()["Data"]
        else:
            self.token = ""
        return r

    def logout(self) -> requests.Response:
        """
        Log out from a wallet. The token is deleted from the WalletClient
        object.
        """
        r = self._httpsession.delete(
            "{}/api/v1/auth/token".format(self.url), headers=self._header())
        if r.status_code == 200:
            self.token = ""
        return r

    def listkeys(self) -> requests.Response:
        return self._httpsession.get(
            "{}/api/v1/keys".format(self.url), headers=self._header())

    def generatekey(
        self,
        passphrase: str,
        metadata: List[Dict[str, str]]
    ) -> requests.Response:
        """
        Generate a new keypair with the given metadata.
        """
        req = {
            "passphrase": passphrase,
            "meta": metadata
        }
        return self._httpsession.post(
            "{}/api/v1/keys".format(self.url), json=req,
            headers=self._header())

    def signtx(self, tx, pubKey) -> requests.Response:
        """
        Sign a transaction.

        tx must be a base64-encoded string, e.g.
        tx = base64.b64encode(someBlob).decode("ascii")

        pubKey must be a hex-encoded string.
        """
        req = {
            "tx": tx,
            "pubKey": pubKey,
            "propagate": False
        }
        return self._httpsession.post(
            "{}/api/v1/messages".format(self.url), headers=self._header(),
            json=req)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import trading_pb2 as proto_dot_api_dot_trading__pb2
from .. import governance_pb2 as proto_dot_governance__pb2
from .. import vega_pb2 as proto_dot_vega__pb2


class tradingStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PrepareSubmitOrder = channel.unary_unary(
        '/api.trading/PrepareSubmitOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.SubmitOrderRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PrepareSubmitOrderResponse.FromString,
        )
    self.PrepareCancelOrder = channel.unary_unary(
        '/api.trading/PrepareCancelOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.CancelOrderRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PrepareCancelOrderResponse.FromString,
        )
    self.PrepareAmendOrder = channel.unary_unary(
        '/api.trading/PrepareAmendOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.AmendOrderRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PrepareAmendOrderResponse.FromString,
        )
    self.SubmitOrder = channel.unary_unary(
        '/api.trading/SubmitOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.SubmitOrderRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.PendingOrder.FromString,
        )
    self.CancelOrder = channel.unary_unary(
        '/api.trading/CancelOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.CancelOrderRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.PendingOrder.FromString,
        )
    self.AmendOrder = channel.unary_unary(
        '/api.trading/AmendOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.AmendOrderRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.PendingOrder.FromString,
        )
    self.SignIn = channel.unary_unary(
        '/api.trading/SignIn',
        request_serializer=proto_dot_api_dot_trading__pb2.SignInRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.SignInResponse.FromString,
        )
    self.NotifyTraderAccount = channel.unary_unary(
        '/api.trading/NotifyTraderAccount',
        request_serializer=proto_dot_api_dot_trading__pb2.NotifyTraderAccountRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.NotifyTraderAccountResponse.FromString,
        )
    self.Withdraw = channel.unary_unary(
        '/api.trading/Withdraw',
        request_serializer=proto_dot_api_dot_trading__pb2.WithdrawRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.WithdrawResponse.FromString,
        )
    self.CheckToken = channel.unary_unary(
        '/api.trading/CheckToken',
        request_serializer=proto_dot_api_dot_trading__pb2.CheckTokenRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.CheckTokenResponse.FromString,
        )
    self.SubmitTransaction = channel.unary_unary(
        '/api.trading/SubmitTransaction',
        request_serializer=proto_dot_api_dot_trading__pb2.SubmitTransactionRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.SubmitTransactionResponse.FromString,
        )
    self.PrepareProposal = channel.unary_unary(
        '/api.trading/PrepareProposal',
        request_serializer=proto_dot_api_dot_trading__pb2.PrepareProposalRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PrepareProposalResponse.FromString,
        )
    self.PrepareVote = channel.unary_unary(
        '/api.trading/PrepareVote',
        request_serializer=proto_dot_api_dot_trading__pb2.PrepareVoteRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PrepareVoteResponse.FromString,
        )


class tradingServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def PrepareSubmitOrder(self, request, context):
    """Prepare a submit order request
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PrepareCancelOrder(self, request, context):
    """Cancel an Order
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PrepareAmendOrder(self, request, context):
    """Amend an Order
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubmitOrder(self, request, context):
    """Submit an Order
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CancelOrder(self, request, context):
    """Cancel an Order
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AmendOrder(self, request, context):
    """Amend an Order
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SignIn(self, request, context):
    """Sign In
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def NotifyTraderAccount(self, request, context):
    """Request balance increase
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Withdraw(self, request, context):
    """Request withdrawal
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CheckToken(self, request, context):
    """Check an API token
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SubmitTransaction(self, request, context):
    """Submit a signed transaction
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PrepareProposal(self, request, context):
    """Governance

    Prepare proposal that can be sent out to the chain (via SubmitTransaction)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PrepareVote(self, request, context):
    """Prepare a vote to be put on the chain (via SubmitTransaction)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_tradingServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PrepareSubmitOrder': grpc.unary_unary_rpc_method_handler(
          servicer.PrepareSubmitOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.SubmitOrderRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PrepareSubmitOrderResponse.SerializeToString,
      ),
      'PrepareCancelOrder': grpc.unary_unary_rpc_method_handler(
          servicer.PrepareCancelOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.CancelOrderRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PrepareCancelOrderResponse.SerializeToString,
      ),
      'PrepareAmendOrder': grpc.unary_unary_rpc_method_handler(
          servicer.PrepareAmendOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.AmendOrderRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PrepareAmendOrderResponse.SerializeToString,
      ),
      'SubmitOrder': grpc.unary_unary_rpc_method_handler(
          servicer.SubmitOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.SubmitOrderRequest.FromString,
          response_serializer=proto_dot_vega__pb2.PendingOrder.SerializeToString,
      ),
      'CancelOrder': grpc.unary_unary_rpc_method_handler(
          servicer.CancelOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.CancelOrderRequest.FromString,
          response_serializer=proto_dot_vega__pb2.PendingOrder.SerializeToString,
      ),
      'AmendOrder': grpc.unary_unary_rpc_method_handler(
          servicer.AmendOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.AmendOrderRequest.FromString,
          response_serializer=proto_dot_vega__pb2.PendingOrder.SerializeToString,
      ),
      'SignIn': grpc.unary_unary_rpc_method_handler(
          servicer.SignIn,
          request_deserializer=proto_dot_api_dot_trading__pb2.SignInRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.SignInResponse.SerializeToString,
      ),
      'NotifyTraderAccount': grpc.unary_unary_rpc_method_handler(
          servicer.NotifyTraderAccount,
          request_deserializer=proto_dot_api_dot_trading__pb2.NotifyTraderAccountRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.NotifyTraderAccountResponse.SerializeToString,
      ),
      'Withdraw': grpc.unary_unary_rpc_method_handler(
          servicer.Withdraw,
          request_deserializer=proto_dot_api_dot_trading__pb2.WithdrawRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.WithdrawResponse.SerializeToString,
      ),
      'CheckToken': grpc.unary_unary_rpc_method_handler(
          servicer.CheckToken,
          request_deserializer=proto_dot_api_dot_trading__pb2.CheckTokenRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.CheckTokenResponse.SerializeToString,
      ),
      'SubmitTransaction': grpc.unary_unary_rpc_method_handler(
          servicer.SubmitTransaction,
          request_deserializer=proto_dot_api_dot_trading__pb2.SubmitTransactionRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.SubmitTransactionResponse.SerializeToString,
      ),
      'PrepareProposal': grpc.unary_unary_rpc_method_handler(
          servicer.PrepareProposal,
          request_deserializer=proto_dot_api_dot_trading__pb2.PrepareProposalRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PrepareProposalResponse.SerializeToString,
      ),
      'PrepareVote': grpc.unary_unary_rpc_method_handler(
          servicer.PrepareVote,
          request_deserializer=proto_dot_api_dot_trading__pb2.PrepareVoteRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PrepareVoteResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'api.trading', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class trading_dataStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.MarketAccounts = channel.unary_unary(
        '/api.trading_data/MarketAccounts',
        request_serializer=proto_dot_api_dot_trading__pb2.MarketAccountsRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarketAccountsResponse.FromString,
        )
    self.PartyAccounts = channel.unary_unary(
        '/api.trading_data/PartyAccounts',
        request_serializer=proto_dot_api_dot_trading__pb2.PartyAccountsRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PartyAccountsResponse.FromString,
        )
    self.Candles = channel.unary_unary(
        '/api.trading_data/Candles',
        request_serializer=proto_dot_api_dot_trading__pb2.CandlesRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.CandlesResponse.FromString,
        )
    self.MarketDataByID = channel.unary_unary(
        '/api.trading_data/MarketDataByID',
        request_serializer=proto_dot_api_dot_trading__pb2.MarketDataByIDRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarketDataByIDResponse.FromString,
        )
    self.MarketsData = channel.unary_unary(
        '/api.trading_data/MarketsData',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarketsDataResponse.FromString,
        )
    self.MarketByID = channel.unary_unary(
        '/api.trading_data/MarketByID',
        request_serializer=proto_dot_api_dot_trading__pb2.MarketByIDRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarketByIDResponse.FromString,
        )
    self.MarketDepth = channel.unary_unary(
        '/api.trading_data/MarketDepth',
        request_serializer=proto_dot_api_dot_trading__pb2.MarketDepthRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarketDepthResponse.FromString,
        )
    self.Markets = channel.unary_unary(
        '/api.trading_data/Markets',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarketsResponse.FromString,
        )
    self.OrderByMarketAndID = channel.unary_unary(
        '/api.trading_data/OrderByMarketAndID',
        request_serializer=proto_dot_api_dot_trading__pb2.OrderByMarketAndIdRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.OrderByMarketAndIdResponse.FromString,
        )
    self.OrderByReference = channel.unary_unary(
        '/api.trading_data/OrderByReference',
        request_serializer=proto_dot_api_dot_trading__pb2.OrderByReferenceRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.OrderByReferenceResponse.FromString,
        )
    self.OrdersByMarket = channel.unary_unary(
        '/api.trading_data/OrdersByMarket',
        request_serializer=proto_dot_api_dot_trading__pb2.OrdersByMarketRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.OrdersByMarketResponse.FromString,
        )
    self.OrdersByParty = channel.unary_unary(
        '/api.trading_data/OrdersByParty',
        request_serializer=proto_dot_api_dot_trading__pb2.OrdersByPartyRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.OrdersByPartyResponse.FromString,
        )
    self.OrderByID = channel.unary_unary(
        '/api.trading_data/OrderByID',
        request_serializer=proto_dot_api_dot_trading__pb2.OrderByIDRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.Order.FromString,
        )
    self.OrderByReferenceID = channel.unary_unary(
        '/api.trading_data/OrderByReferenceID',
        request_serializer=proto_dot_api_dot_trading__pb2.OrderByReferenceIDRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.Order.FromString,
        )
    self.MarginLevels = channel.unary_unary(
        '/api.trading_data/MarginLevels',
        request_serializer=proto_dot_api_dot_trading__pb2.MarginLevelsRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.MarginLevelsResponse.FromString,
        )
    self.Parties = channel.unary_unary(
        '/api.trading_data/Parties',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PartiesResponse.FromString,
        )
    self.PartyByID = channel.unary_unary(
        '/api.trading_data/PartyByID',
        request_serializer=proto_dot_api_dot_trading__pb2.PartyByIDRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PartyByIDResponse.FromString,
        )
    self.PositionsByParty = channel.unary_unary(
        '/api.trading_data/PositionsByParty',
        request_serializer=proto_dot_api_dot_trading__pb2.PositionsByPartyRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.PositionsByPartyResponse.FromString,
        )
    self.LastTrade = channel.unary_unary(
        '/api.trading_data/LastTrade',
        request_serializer=proto_dot_api_dot_trading__pb2.LastTradeRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.LastTradeResponse.FromString,
        )
    self.TradesByMarket = channel.unary_unary(
        '/api.trading_data/TradesByMarket',
        request_serializer=proto_dot_api_dot_trading__pb2.TradesByMarketRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.TradesByMarketResponse.FromString,
        )
    self.TradesByOrder = channel.unary_unary(
        '/api.trading_data/TradesByOrder',
        request_serializer=proto_dot_api_dot_trading__pb2.TradesByOrderRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.TradesByOrderResponse.FromString,
        )
    self.TradesByParty = channel.unary_unary(
        '/api.trading_data/TradesByParty',
        request_serializer=proto_dot_api_dot_trading__pb2.TradesByPartyRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.TradesByPartyResponse.FromString,
        )
    self.GetProposals = channel.unary_unary(
        '/api.trading_data/GetProposals',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.GetProposalsResponse.FromString,
        )
    self.GetOpenProposals = channel.unary_unary(
        '/api.trading_data/GetOpenProposals',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.GetProposalsResponse.FromString,
        )
    self.GetProposalByID = channel.unary_unary(
        '/api.trading_data/GetProposalByID',
        request_serializer=proto_dot_api_dot_trading__pb2.GetProposalByIDRequest.SerializeToString,
        response_deserializer=proto_dot_governance__pb2.ProposalVote.FromString,
        )
    self.GetProposalByReference = channel.unary_unary(
        '/api.trading_data/GetProposalByReference',
        request_serializer=proto_dot_api_dot_trading__pb2.GetProposalByReferenceRequest.SerializeToString,
        response_deserializer=proto_dot_governance__pb2.ProposalVote.FromString,
        )
    self.ObserveProposals = channel.unary_stream(
        '/api.trading_data/ObserveProposals',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_governance__pb2.ProposalVote.FromString,
        )
    self.Statistics = channel.unary_unary(
        '/api.trading_data/Statistics',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.Statistics.FromString,
        )
    self.GetVegaTime = channel.unary_unary(
        '/api.trading_data/GetVegaTime',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.VegaTimeResponse.FromString,
        )
    self.AccountsSubscribe = channel.unary_stream(
        '/api.trading_data/AccountsSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.AccountsSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.Account.FromString,
        )
    self.CandlesSubscribe = channel.unary_stream(
        '/api.trading_data/CandlesSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.CandlesSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.Candle.FromString,
        )
    self.MarginLevelsSubscribe = channel.unary_stream(
        '/api.trading_data/MarginLevelsSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.MarginLevelsSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.MarginLevels.FromString,
        )
    self.MarketDepthSubscribe = channel.unary_stream(
        '/api.trading_data/MarketDepthSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.MarketDepthSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.MarketDepth.FromString,
        )
    self.MarketsDataSubscribe = channel.unary_stream(
        '/api.trading_data/MarketsDataSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.MarketsDataSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.MarketData.FromString,
        )
    self.OrdersSubscribe = channel.unary_stream(
        '/api.trading_data/OrdersSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.OrdersSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.OrdersStream.FromString,
        )
    self.PositionsSubscribe = channel.unary_stream(
        '/api.trading_data/PositionsSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.PositionsSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.Position.FromString,
        )
    self.TradesSubscribe = channel.unary_stream(
        '/api.trading_data/TradesSubscribe',
        request_serializer=proto_dot_api_dot_trading__pb2.TradesSubscribeRequest.SerializeToString,
        response_deserializer=proto_dot_api_dot_trading__pb2.TradesStream.FromString,
        )
    self.TransferResponsesSubscribe = channel.unary_stream(
        '/api.trading_data/TransferResponsesSubscribe',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=proto_dot_vega__pb2.TransferResponse.FromString,
        )


class trading_dataServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def MarketAccounts(self, request, context):
    """Accounts

    Get a list of Accounts by Market
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartyAccounts(self, request, context):
    """Get a list of Accounts by Party
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Candles(self, request, context):
    """Candles

    Get a list of Candles by Market
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarketDataByID(self, request, context):
    """Market Data

    Get Market Data by MarketID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarketsData(self, request, context):
    """Get a list of Market Data
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarketByID(self, request, context):
    """Markets

    Get a Market by ID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarketDepth(self, request, context):
    """Get Market Depth
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Markets(self, request, context):
    """Get a list of Markets
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrderByMarketAndID(self, request, context):
    """Orders

    Get an Order by Market and OrderID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrderByReference(self, request, context):
    """Get an Order by Pending Order reference (UUID)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrdersByMarket(self, request, context):
    """Get a list of Orders by Market
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrdersByParty(self, request, context):
    """Get a list of Orders by Party
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrderByID(self, request, context):
    """Get a specific order by orderID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrderByReferenceID(self, request, context):
    """Get a specific order by referenceID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarginLevels(self, request, context):
    """Parties

    Get Margin Levels by PartyID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Parties(self, request, context):
    """Get a list of Parties
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PartyByID(self, request, context):
    """Get a Party by ID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PositionsByParty(self, request, context):
    """Positions

    Get a list of Positions by Party
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LastTrade(self, request, context):
    """Trades

    Get latest Trade
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TradesByMarket(self, request, context):
    """Get a list of Trades by Market
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TradesByOrder(self, request, context):
    """Get a list of Trades by Order
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TradesByParty(self, request, context):
    """Get a list of Trades by Party
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetProposals(self, request, context):
    """Governance

    Get all proposals
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetOpenProposals(self, request, context):
    """Get all OPEN proposals
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetProposalByID(self, request, context):
    """Get a proposal by ID
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetProposalByReference(self, request, context):
    """Get a proposal by reference
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ObserveProposals(self, request, context):
    """Subscribe to a stream of updates to proposal data
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Statistics(self, request, context):
    """Misc

    Get Statistics
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVegaTime(self, request, context):
    """Get Time
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AccountsSubscribe(self, request, context):
    """Subscribe to a stream of Accounts
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def CandlesSubscribe(self, request, context):
    """Subscribe to a stream of Candles
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarginLevelsSubscribe(self, request, context):
    """Subscribe to a stream of Margin Levels
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarketDepthSubscribe(self, request, context):
    """Subscribe to a stream of Market Depth
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MarketsDataSubscribe(self, request, context):
    """Subscribe to a stream of Markets Data
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OrdersSubscribe(self, request, context):
    """Subscribe to a stream of Orders
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PositionsSubscribe(self, request, context):
    """Subscribe to a stream of Positions
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TradesSubscribe(self, request, context):
    """Subscribe to a stream of Trades
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def TransferResponsesSubscribe(self, request, context):
    """Subscribe to a stream of Transfer Responses
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_trading_dataServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'MarketAccounts': grpc.unary_unary_rpc_method_handler(
          servicer.MarketAccounts,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarketAccountsRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarketAccountsResponse.SerializeToString,
      ),
      'PartyAccounts': grpc.unary_unary_rpc_method_handler(
          servicer.PartyAccounts,
          request_deserializer=proto_dot_api_dot_trading__pb2.PartyAccountsRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PartyAccountsResponse.SerializeToString,
      ),
      'Candles': grpc.unary_unary_rpc_method_handler(
          servicer.Candles,
          request_deserializer=proto_dot_api_dot_trading__pb2.CandlesRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.CandlesResponse.SerializeToString,
      ),
      'MarketDataByID': grpc.unary_unary_rpc_method_handler(
          servicer.MarketDataByID,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarketDataByIDRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarketDataByIDResponse.SerializeToString,
      ),
      'MarketsData': grpc.unary_unary_rpc_method_handler(
          servicer.MarketsData,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarketsDataResponse.SerializeToString,
      ),
      'MarketByID': grpc.unary_unary_rpc_method_handler(
          servicer.MarketByID,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarketByIDRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarketByIDResponse.SerializeToString,
      ),
      'MarketDepth': grpc.unary_unary_rpc_method_handler(
          servicer.MarketDepth,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarketDepthRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarketDepthResponse.SerializeToString,
      ),
      'Markets': grpc.unary_unary_rpc_method_handler(
          servicer.Markets,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarketsResponse.SerializeToString,
      ),
      'OrderByMarketAndID': grpc.unary_unary_rpc_method_handler(
          servicer.OrderByMarketAndID,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrderByMarketAndIdRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.OrderByMarketAndIdResponse.SerializeToString,
      ),
      'OrderByReference': grpc.unary_unary_rpc_method_handler(
          servicer.OrderByReference,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrderByReferenceRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.OrderByReferenceResponse.SerializeToString,
      ),
      'OrdersByMarket': grpc.unary_unary_rpc_method_handler(
          servicer.OrdersByMarket,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrdersByMarketRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.OrdersByMarketResponse.SerializeToString,
      ),
      'OrdersByParty': grpc.unary_unary_rpc_method_handler(
          servicer.OrdersByParty,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrdersByPartyRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.OrdersByPartyResponse.SerializeToString,
      ),
      'OrderByID': grpc.unary_unary_rpc_method_handler(
          servicer.OrderByID,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrderByIDRequest.FromString,
          response_serializer=proto_dot_vega__pb2.Order.SerializeToString,
      ),
      'OrderByReferenceID': grpc.unary_unary_rpc_method_handler(
          servicer.OrderByReferenceID,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrderByReferenceIDRequest.FromString,
          response_serializer=proto_dot_vega__pb2.Order.SerializeToString,
      ),
      'MarginLevels': grpc.unary_unary_rpc_method_handler(
          servicer.MarginLevels,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarginLevelsRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.MarginLevelsResponse.SerializeToString,
      ),
      'Parties': grpc.unary_unary_rpc_method_handler(
          servicer.Parties,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PartiesResponse.SerializeToString,
      ),
      'PartyByID': grpc.unary_unary_rpc_method_handler(
          servicer.PartyByID,
          request_deserializer=proto_dot_api_dot_trading__pb2.PartyByIDRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PartyByIDResponse.SerializeToString,
      ),
      'PositionsByParty': grpc.unary_unary_rpc_method_handler(
          servicer.PositionsByParty,
          request_deserializer=proto_dot_api_dot_trading__pb2.PositionsByPartyRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.PositionsByPartyResponse.SerializeToString,
      ),
      'LastTrade': grpc.unary_unary_rpc_method_handler(
          servicer.LastTrade,
          request_deserializer=proto_dot_api_dot_trading__pb2.LastTradeRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.LastTradeResponse.SerializeToString,
      ),
      'TradesByMarket': grpc.unary_unary_rpc_method_handler(
          servicer.TradesByMarket,
          request_deserializer=proto_dot_api_dot_trading__pb2.TradesByMarketRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.TradesByMarketResponse.SerializeToString,
      ),
      'TradesByOrder': grpc.unary_unary_rpc_method_handler(
          servicer.TradesByOrder,
          request_deserializer=proto_dot_api_dot_trading__pb2.TradesByOrderRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.TradesByOrderResponse.SerializeToString,
      ),
      'TradesByParty': grpc.unary_unary_rpc_method_handler(
          servicer.TradesByParty,
          request_deserializer=proto_dot_api_dot_trading__pb2.TradesByPartyRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.TradesByPartyResponse.SerializeToString,
      ),
      'GetProposals': grpc.unary_unary_rpc_method_handler(
          servicer.GetProposals,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.GetProposalsResponse.SerializeToString,
      ),
      'GetOpenProposals': grpc.unary_unary_rpc_method_handler(
          servicer.GetOpenProposals,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.GetProposalsResponse.SerializeToString,
      ),
      'GetProposalByID': grpc.unary_unary_rpc_method_handler(
          servicer.GetProposalByID,
          request_deserializer=proto_dot_api_dot_trading__pb2.GetProposalByIDRequest.FromString,
          response_serializer=proto_dot_governance__pb2.ProposalVote.SerializeToString,
      ),
      'GetProposalByReference': grpc.unary_unary_rpc_method_handler(
          servicer.GetProposalByReference,
          request_deserializer=proto_dot_api_dot_trading__pb2.GetProposalByReferenceRequest.FromString,
          response_serializer=proto_dot_governance__pb2.ProposalVote.SerializeToString,
      ),
      'ObserveProposals': grpc.unary_stream_rpc_method_handler(
          servicer.ObserveProposals,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_governance__pb2.ProposalVote.SerializeToString,
      ),
      'Statistics': grpc.unary_unary_rpc_method_handler(
          servicer.Statistics,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_vega__pb2.Statistics.SerializeToString,
      ),
      'GetVegaTime': grpc.unary_unary_rpc_method_handler(
          servicer.GetVegaTime,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.VegaTimeResponse.SerializeToString,
      ),
      'AccountsSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.AccountsSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.AccountsSubscribeRequest.FromString,
          response_serializer=proto_dot_vega__pb2.Account.SerializeToString,
      ),
      'CandlesSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.CandlesSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.CandlesSubscribeRequest.FromString,
          response_serializer=proto_dot_vega__pb2.Candle.SerializeToString,
      ),
      'MarginLevelsSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.MarginLevelsSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarginLevelsSubscribeRequest.FromString,
          response_serializer=proto_dot_vega__pb2.MarginLevels.SerializeToString,
      ),
      'MarketDepthSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.MarketDepthSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarketDepthSubscribeRequest.FromString,
          response_serializer=proto_dot_vega__pb2.MarketDepth.SerializeToString,
      ),
      'MarketsDataSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.MarketsDataSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.MarketsDataSubscribeRequest.FromString,
          response_serializer=proto_dot_vega__pb2.MarketData.SerializeToString,
      ),
      'OrdersSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.OrdersSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.OrdersSubscribeRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.OrdersStream.SerializeToString,
      ),
      'PositionsSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.PositionsSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.PositionsSubscribeRequest.FromString,
          response_serializer=proto_dot_vega__pb2.Position.SerializeToString,
      ),
      'TradesSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.TradesSubscribe,
          request_deserializer=proto_dot_api_dot_trading__pb2.TradesSubscribeRequest.FromString,
          response_serializer=proto_dot_api_dot_trading__pb2.TradesStream.SerializeToString,
      ),
      'TransferResponsesSubscribe': grpc.unary_stream_rpc_method_handler(
          servicer.TransferResponsesSubscribe,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=proto_dot_vega__pb2.TransferResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'api.trading_data', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/governance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .markets_pb2 import (DESCRIPTOR as markets_DESCRIPTOR, _MARKET as markets_MARKET)


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/governance.proto',
  package='vega',
  syntax='proto3',
  serialized_options=b'Z\037code.vegaprotocol.io/vega/proto',
  serialized_pb=b'\n\x16proto/governance.proto\x12\x04vega\x1a\x13proto/markets.proto\"\xa1\x01\n\x14NetworkConfiguration\x12\x19\n\x11minCloseInSeconds\x18\x01 \x01(\x03\x12\x19\n\x11maxCloseInSeconds\x18\x02 \x01(\x03\x12\x19\n\x11minEnactInSeconds\x18\x03 \x01(\x03\x12\x19\n\x11maxEnactInSeconds\x18\x04 \x01(\x03\x12\x1d\n\x15minParticipationStake\x18\x05 \x01(\x04\"\x0e\n\x0cUpdateMarket\"*\n\tNewMarket\x12\x1d\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x0c.vega.Market\"<\n\rUpdateNetwork\x12+\n\x07\x63hanges\x18\x01 \x01(\x0b\x32\x1a.vega.NetworkConfiguration\"\xee\x01\n\rProposalTerms\x12\x18\n\x10\x63losingTimestamp\x18\x01 \x01(\x03\x12\x1a\n\x12\x65nactmentTimestamp\x18\x02 \x01(\x03\x12\x1d\n\x15minParticipationStake\x18\x03 \x01(\x04\x12*\n\x0cupdateMarket\x18\x65 \x01(\x0b\x32\x12.vega.UpdateMarketH\x00\x12$\n\tnewMarket\x18\x66 \x01(\x0b\x32\x0f.vega.NewMarketH\x00\x12,\n\rupdateNetwork\x18g \x01(\x0b\x32\x13.vega.UpdateNetworkH\x00\x42\x08\n\x06\x63hange\"a\n\x0cProposalVote\x12 \n\x08proposal\x18\x01 \x01(\x0b\x32\x0e.vega.Proposal\x12\x17\n\x03yes\x18\x02 \x03(\x0b\x32\n.vega.Vote\x12\x16\n\x02no\x18\x03 \x03(\x0b\x32\n.vega.Vote\"\xea\x01\n\x08Proposal\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0f\n\x07partyID\x18\x03 \x01(\t\x12#\n\x05state\x18\x04 \x01(\x0e\x32\x14.vega.Proposal.State\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\"\n\x05terms\x18\x06 \x01(\x0b\x32\x13.vega.ProposalTerms\"R\n\x05State\x12\n\n\x06\x46\x41ILED\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\n\n\x06PASSED\x10\x02\x12\x0c\n\x08REJECTED\x10\x03\x12\x0c\n\x08\x44\x45\x43LINED\x10\x04\x12\x0b\n\x07\x45NACTED\x10\x05\"f\n\x04Vote\x12\x0f\n\x07partyID\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0e\x32\x10.vega.Vote.Value\x12\x12\n\nproposalID\x18\x03 \x01(\t\"\x18\n\x05Value\x12\x06\n\x02NO\x10\x00\x12\x07\n\x03YES\x10\x01\x42!Z\x1f\x63ode.vegaprotocol.io/vega/protob\x06proto3'
  ,
  dependencies=[markets_DESCRIPTOR,])



_PROPOSAL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='vega.Proposal.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PASSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECLINED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENACTED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=832,
  serialized_end=914,
)
_sym_db.RegisterEnumDescriptor(_PROPOSAL_STATE)

_VOTE_VALUE = _descriptor.EnumDescriptor(
  name='Value',
  full_name='vega.Vote.Value',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YES', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=994,
  serialized_end=1018,
)
_sym_db.RegisterEnumDescriptor(_VOTE_VALUE)


_NETWORKCONFIGURATION = _descriptor.Descriptor(
  name='NetworkConfiguration',
  full_name='vega.NetworkConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='minCloseInSeconds', full_name='vega.NetworkConfiguration.minCloseInSeconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxCloseInSeconds', full_name='vega.NetworkConfiguration.maxCloseInSeconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minEnactInSeconds', full_name='vega.NetworkConfiguration.minEnactInSeconds', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxEnactInSeconds', full_name='vega.NetworkConfiguration.maxEnactInSeconds', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minParticipationStake', full_name='vega.NetworkConfiguration.minParticipationStake', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=215,
)


_UPDATEMARKET = _descriptor.Descriptor(
  name='UpdateMarket',
  full_name='vega.UpdateMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=231,
)


_NEWMARKET = _descriptor.Descriptor(
  name='NewMarket',
  full_name='vega.NewMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.NewMarket.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=275,
)


_UPDATENETWORK = _descriptor.Descriptor(
  name='UpdateNetwork',
  full_name='vega.UpdateNetwork',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='changes', full_name='vega.UpdateNetwork.changes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=337,
)


_PROPOSALTERMS = _descriptor.Descriptor(
  name='ProposalTerms',
  full_name='vega.ProposalTerms',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='closingTimestamp', full_name='vega.ProposalTerms.closingTimestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enactmentTimestamp', full_name='vega.ProposalTerms.enactmentTimestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minParticipationStake', full_name='vega.ProposalTerms.minParticipationStake', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateMarket', full_name='vega.ProposalTerms.updateMarket', index=3,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newMarket', full_name='vega.ProposalTerms.newMarket', index=4,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateNetwork', full_name='vega.ProposalTerms.updateNetwork', index=5,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='change', full_name='vega.ProposalTerms.change',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=340,
  serialized_end=578,
)


_PROPOSALVOTE = _descriptor.Descriptor(
  name='ProposalVote',
  full_name='vega.ProposalVote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal', full_name='vega.ProposalVote.proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yes', full_name='vega.ProposalVote.yes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='no', full_name='vega.ProposalVote.no', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=677,
)


_PROPOSAL = _descriptor.Descriptor(
  name='Proposal',
  full_name='vega.Proposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ID', full_name='vega.Proposal.ID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.Proposal.reference', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.Proposal.partyID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='vega.Proposal.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='vega.Proposal.timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='terms', full_name='vega.Proposal.terms', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROPOSAL_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=680,
  serialized_end=914,
)


_VOTE = _descriptor.Descriptor(
  name='Vote',
  full_name='vega.Vote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partyID', full_name='vega.Vote.partyID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.Vote.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposalID', full_name='vega.Vote.proposalID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VOTE_VALUE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=916,
  serialized_end=1018,
)

_NEWMARKET.fields_by_name['changes'].message_type = markets_MARKET
_UPDATENETWORK.fields_by_name['changes'].message_type = _NETWORKCONFIGURATION
_PROPOSALTERMS.fields_by_name['updateMarket'].message_type = _UPDATEMARKET
_PROPOSALTERMS.fields_by_name['newMarket'].message_type = _NEWMARKET
_PROPOSALTERMS.fields_by_name['updateNetwork'].message_type = _UPDATENETWORK
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['updateMarket'])
_PROPOSALTERMS.fields_by_name['updateMarket'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['newMarket'])
_PROPOSALTERMS.fields_by_name['newMarket'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALTERMS.oneofs_by_name['change'].fields.append(
  _PROPOSALTERMS.fields_by_name['updateNetwork'])
_PROPOSALTERMS.fields_by_name['updateNetwork'].containing_oneof = _PROPOSALTERMS.oneofs_by_name['change']
_PROPOSALVOTE.fields_by_name['proposal'].message_type = _PROPOSAL
_PROPOSALVOTE.fields_by_name['yes'].message_type = _VOTE
_PROPOSALVOTE.fields_by_name['no'].message_type = _VOTE
_PROPOSAL.fields_by_name['state'].enum_type = _PROPOSAL_STATE
_PROPOSAL.fields_by_name['terms'].message_type = _PROPOSALTERMS
_PROPOSAL_STATE.containing_type = _PROPOSAL
_VOTE.fields_by_name['value'].enum_type = _VOTE_VALUE
_VOTE_VALUE.containing_type = _VOTE
DESCRIPTOR.message_types_by_name['NetworkConfiguration'] = _NETWORKCONFIGURATION
DESCRIPTOR.message_types_by_name['UpdateMarket'] = _UPDATEMARKET
DESCRIPTOR.message_types_by_name['NewMarket'] = _NEWMARKET
DESCRIPTOR.message_types_by_name['UpdateNetwork'] = _UPDATENETWORK
DESCRIPTOR.message_types_by_name['ProposalTerms'] = _PROPOSALTERMS
DESCRIPTOR.message_types_by_name['ProposalVote'] = _PROPOSALVOTE
DESCRIPTOR.message_types_by_name['Proposal'] = _PROPOSAL
DESCRIPTOR.message_types_by_name['Vote'] = _VOTE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NetworkConfiguration = _reflection.GeneratedProtocolMessageType('NetworkConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKCONFIGURATION,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NetworkConfiguration)
  })
_sym_db.RegisterMessage(NetworkConfiguration)

UpdateMarket = _reflection.GeneratedProtocolMessageType('UpdateMarket', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMARKET,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.UpdateMarket)
  })
_sym_db.RegisterMessage(UpdateMarket)

NewMarket = _reflection.GeneratedProtocolMessageType('NewMarket', (_message.Message,), {
  'DESCRIPTOR' : _NEWMARKET,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.NewMarket)
  })
_sym_db.RegisterMessage(NewMarket)

UpdateNetwork = _reflection.GeneratedProtocolMessageType('UpdateNetwork', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENETWORK,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.UpdateNetwork)
  })
_sym_db.RegisterMessage(UpdateNetwork)

ProposalTerms = _reflection.GeneratedProtocolMessageType('ProposalTerms', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALTERMS,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.ProposalTerms)
  })
_sym_db.RegisterMessage(ProposalTerms)

ProposalVote = _reflection.GeneratedProtocolMessageType('ProposalVote', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALVOTE,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.ProposalVote)
  })
_sym_db.RegisterMessage(ProposalVote)

Proposal = _reflection.GeneratedProtocolMessageType('Proposal', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSAL,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.Proposal)
  })
_sym_db.RegisterMessage(Proposal)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), {
  'DESCRIPTOR' : _VOTE,
  '__module__' : 'proto.governance_pb2'
  # @@protoc_insertion_point(class_scope:vega.Vote)
  })
_sym_db.RegisterMessage(Vote)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from .api import API
from .grpc import VegaTradingDataClient as grpcTradingDataClient
from .rest import VegaTradingDataClient as restTradingDataClient


class VegaTradingDataClient(object):

    def __init__(
        self,
        api: API,
        url: str
    ):
        if api == API.GRPC:
            self._impl = grpcTradingDataClient(url)
        elif api == API.REST:
            self._impl = restTradingDataClient(url)
        else:
            raise Exception("API not implemented")

    def __getattr__(self, funcname):
        return getattr(self._impl, funcname)



from .api import API
from .vegatradingclient import VegaTradingClient
from .vegatradingdataclient import VegaTradingDataClient
from .walletclient import WalletClient
from . import grpc

__all__ = [
    "API",
    "VegaTradingClient",
    "VegaTradingDataClient",
    "WalletClient",
    "grpc"
]



from .api import API
from .grpc import VegaTradingClient as grpcTradingClient
from .rest import VegaTradingClient as restTradingClient


class VegaTradingClient(object):

    def __init__(
        self,
        api: API,
        url: str
    ):
        if api == API.GRPC:
            self._impl = grpcTradingClient(url)
        elif api == API.REST:
            self._impl = restTradingClient(url)
        else:
            raise Exception("API not implemented")

    def __getattr__(self, funcname):
        return getattr(self._impl, funcname)



from google.protobuf.empty_pb2 import Empty

from .fixtures import tradingdataGRPC, tradingdataREST  # noqa: F401


def test_MarketsData(tradingdataGRPC, tradingdataREST):  # noqa: F811
    g = tradingdataGRPC.MarketsData(Empty())
    r = tradingdataREST.MarketsData(Empty())

    # The order (of MarketData objects in the list) is not guaranteed.
    gIDs = set(md.market for md in g.marketsData)
    rIDs = set(md.market for md in r.marketsData)
    assert gIDs == rIDs



import requests
from google.protobuf.empty_pb2 import Empty

from ..grpc import api

from .convert import convert_obj, errStr


class VegaTradingDataClient(object):
    """
    The Vega Trading Data Client talks to a back-end node.
    """

    def __init__(
        self,
        url: str
    ) -> None:
        if url is None:
            raise Exception("Missing node URL")
        self.url = url

        self._httpsession = requests.Session()

    # MarketAccounts,MarketAccountsRequest,MarketAccountsResponse
    # PartyAccounts,PartyAccountsRequest,PartyAccountsResponse
    # Candles,CandlesRequest,CandlesResponse
    # MarketDataByID,MarketDataByIDRequest,MarketDataByIDResponse

    def MarketsData(
        self,
        _: Empty
    ) -> api.trading.MarketsDataResponse:
        r = self._httpsession.get(
            "{}/markets-data".format(self.url))
        if r.status_code != 200:
            raise Exception(errStr(r))
        return convert_obj(r.json(), api.trading.MarketsDataResponse())

    def MarketByID(
        self,
        req: api.trading.MarketByIDRequest
    ) -> api.trading.MarketByIDResponse:
        r = self._httpsession.get(
            "{}/markets/{}".format(self.url, req.marketID))
        if r.status_code != 200:
            raise Exception(errStr(r))
        return convert_obj(r.json(), api.trading.MarketByIDResponse())

    # MarketDepth,MarketDepthRequest,MarketDepthResponse

    def Markets(
        self,
        _: Empty
    ) -> api.trading.MarketsResponse:
        r = self._httpsession.get("{}/markets".format(self.url))
        if r.status_code != 200:
            raise Exception(errStr(r))
        return convert_obj(r.json(), api.trading.MarketsResponse())

    # OrderByMarketAndID,OrderByMarketAndIdRequest,OrderByMarketAndIdResponse
    # OrderByReference,OrderByReferenceRequest,OrderByReferenceResponse
    # OrdersByMarket,OrdersByMarketRequest,OrdersByMarketResponse
    # OrdersByParty,OrdersByPartyRequest,OrdersByPartyResponse
    # MarginLevels,MarginLevelsRequest,MarginLevelsResponse
    # Parties,.google.protobuf.Empty,PartiesResponse
    # PartyByID,PartyByIDRequest,PartyByIDResponse
    # PositionsByParty,PositionsByPartyRequest,PositionsByPartyResponse
    # LastTrade,LastTradeRequest,LastTradeResponse
    # TradesByMarket,TradesByMarketRequest,TradesByMarketResponse
    # TradesByOrder,TradesByOrderRequest,TradesByOrderResponse
    # TradesByParty,TradesByPartyRequest,TradesByPartyResponse
    # Statistics,.google.protobuf.Empty,.vega.Statistics
    # GetVegaTime,.google.protobuf.Empty,VegaTimeResponse
    # AccountsSubscribe,AccountsSubscribeRequest,.vega.Account
    # CandlesSubscribe,CandlesSubscribeRequest,.vega.Candle
    # MarginLevelsSubscribe,MarginLevelsSubscribeRequest,.vega.MarginLevels
    # MarketDepthSubscribe,MarketDepthSubscribeRequest,.vega.MarketDepth
    # MarketsDataSubscribe,MarketsDataSubscribeRequest,.vega.MarketData
    # OrdersSubscribe,OrdersSubscribeRequest,OrdersStream
    # PositionsSubscribe,PositionsSubscribeRequest,.vega.Position
    # TradesSubscribe,TradesSubscribeRequest,TradesStream
    # TransferResponsesSubscribe,.google.protobuf.Empty,.vega.TransferResponse



import requests
from typing import Any, Dict

from ..grpc import markets, vega


def errStr(r: requests.Response) -> str:
    return "request failed: HTTP {} {}".format(r.status_code, r.text)


_mappings = {
    "api.MarketByIDResponse.market": markets.Market,
    "api.MarketsDataResponse.marketsData": vega.MarketData,
    "api.MarketsResponse.markets": markets.Market,
    "vega.Future.ethereumEvent": markets.EthereumEvent,
    "vega.Instrument.future": markets.Future,
    "vega.Instrument.metadata": markets.InstrumentMetadata,
    "vega.LogNormalRiskModel.params": markets.LogNormalModelParams,
    "vega.MarginCalculator.scalingFactors": markets.ScalingFactors,
    "vega.Market.continuous": markets.ContinuousTrading,
    "vega.Market.tradableInstrument": markets.TradableInstrument,
    "vega.TradableInstrument.instrument": markets.Instrument,
    "vega.TradableInstrument.logNormalRiskModel": markets.LogNormalRiskModel,
    "vega.TradableInstrument.marginCalculator": markets.MarginCalculator
}


def convert_complextype(j, r, f):

    if f.full_name in _mappings:
        # print("Setting obj {} ({})".format(f.json_name, f.full_name))
        innerType = _mappings[f.full_name]
        if isinstance(j[f.json_name], list):
            getattr(r, f.json_name).MergeFrom([
                convert_obj(item, innerType()) for item in j[f.json_name]
            ])
        else:
            inner = innerType()
            convert_obj(j[f.json_name], inner)
            getattr(r, f.json_name).CopyFrom(inner)
        return

    raise Exception("not implemented: {}".format(f.full_name))


def convert_field(j, r, f):
    if f.json_name not in j:
        return

    if f.type == 11:  # object
        convert_complextype(j, r, f)
    elif f.type == 9:  # string
        if isinstance(j[f.json_name], list):
            # print("list {}: {}".format(f.json_name, j[f.json_name]))
            getattr(r, f.json_name).MergeFrom(j[f.json_name])
        elif isinstance(j[f.json_name], str):
            # print("str {}: {}".format(f.json_name, j[f.json_name]))
            setattr(r, f.json_name, j[f.json_name])
        else:
            raise Exception("not implemented: type 9, but not string or list")
    elif f.type == 4:  # int
        # print("int {}: {}".format(f.json_name, j[f.json_name]))
        setattr(r, f.json_name, int(j[f.json_name]))
    elif f.type == 3:  # timestamp
        # print("timestamp {}: {}".format(f.json_name, j[f.json_name]))
        setattr(r, f.json_name, int(j[f.json_name]))
    elif f.type == 1:  # float
        # print("float {}: {}".format(f.json_name, j[f.json_name]))
        setattr(r, f.json_name, float(j[f.json_name]))
    else:
        raise Exception("type {} not implemented for {}".format(
            f.type, f.full_name))


def convert_obj(
    j: Dict[str, Any],  # dict as returned from requests.Response.json()
    r  # empty response object
):
    for f in r.DESCRIPTOR.fields:
        convert_field(j, r, f)

    return r



from google.protobuf.empty_pb2 import Empty

import vegaapiclient as vac

from .fixtures import tradingdataGRPC, tradingdataREST  # noqa: F401


def test_MarketByID(tradingdataGRPC, tradingdataREST):  # noqa: F811
    markets = tradingdataGRPC.Markets(Empty()).markets
    assert len(markets) > 0
    marketID = markets[0].id

    req = vac.grpc.api.trading.MarketByIDRequest(marketID=marketID)
    marketGRPC = tradingdataGRPC.MarketByID(req)
    marketREST = tradingdataREST.MarketByID(req)

    assert marketGRPC.SerializeToString() == marketREST.SerializeToString()


def test_Markets(tradingdataGRPC, tradingdataREST):  # noqa: F811
    marketsGRPC = tradingdataGRPC.Markets(Empty())
    marketsREST = tradingdataREST.Markets(Empty())
    assert marketsGRPC.SerializeToString() == marketsREST.SerializeToString()



def deprecated(reason: str):
    def state_deprecated(f):
        def new_f(*args, **kwargs):
            print("Warning: {} is deprecated: {}".format(f.__name__, reason))
            return f(*args, **kwargs)

        return new_f

    return state_deprecated
